@@ -31,8 +31,14 @@ def _handle_route(self:Server, reqpath:str, request_headers):
                 route_parameters[param.name] = int(path[pn])
             elif param.type == RouteParamType.string:
                 route_parameters[param.name] = path[pn]
-    
-    if route_parameters == {}:
-        return self.routes[route_key](request_headers).generate()
-    else:
-        return self.routes[route_key](request_headers, route_parameters).generate()
\ No newline at end of file
+    try:
+        if route_parameters == {}:
+            return self.routes[route_key](request_headers).generate()
+        else:
+            return self.routes[route_key](request_headers, route_parameters).generate()
+    except TypeError as e:
+        if self.debug:
+            print(f"Route ({route_key}) has thrown a type error.\n\n  Perhapse the route's function has the wrong number of parameters.")
+        return self.error_404(reqpath)
+    except:
+        return self.error_404(reqpath)
\ No newline at end of file
