@@ -10,8 +10,12 @@ class ServerTest(unittest.TestCase):
         def index(headers):
             return Response("test", ContentType.html)
 
-        @app.route("page/(num)")
+        @app.route("page/[num]")
         def index(headers, params):
             return Response(f"num: {params['num']}", ContentType.html)
         
+        @app.route("page")
+        def index(headers):
+            return Response(f"page", ContentType.html)
+        
         app.run()
\ No newline at end of file
